diff --git a/core/modules/block/src/Tests/BlockConfigSchemaTest.php b/core/modules/block/src/Tests/BlockConfigSchemaTest.php
index ccd0a73..cb6ff69 100644
--- a/core/modules/block/src/Tests/BlockConfigSchemaTest.php
+++ b/core/modules/block/src/Tests/BlockConfigSchemaTest.php
@@ -74,7 +74,7 @@ public function testBlockConfigSchema() {
       $id = strtolower($this->randomMachineName());
       $block = Block::create(array(
         'id' => $id,
-        'theme' => 'stark',
+        'theme' => 'classy',
         'weight' => 00,
         'status' => TRUE,
         'region' => 'content',
diff --git a/core/modules/block/src/Tests/BlockTest.php b/core/modules/block/src/Tests/BlockTest.php
index 3d9a348..756c71a 100644
--- a/core/modules/block/src/Tests/BlockTest.php
+++ b/core/modules/block/src/Tests/BlockTest.php
@@ -190,7 +190,7 @@ public function testBlockThemeSelector() {
     // Install all themes.
     \Drupal::service('theme_handler')->install(array('bartik', 'seven'));
     $theme_settings = $this->container->get('config.factory')->get('system.theme');
-    foreach (array('bartik', 'stark', 'seven') as $theme) {
+    foreach (array('bartik', 'classy', 'seven') as $theme) {
       $this->drupalGet('admin/structure/block/list/' . $theme);
       $this->assertTitle(t('Block layout') . ' | Drupal');
       // Select the 'Powered by Drupal' block to be placed.
@@ -326,7 +326,7 @@ public function testBlockCacheTags() {
     $cid = sha1(implode(':', $cid_parts));
     $cache_entry = \Drupal::cache('render')->get($cid);
     $expected_cache_tags = array(
-      'theme:stark',
+      'theme:classy',
       'theme_global_settings',
       'block_view',
       'block:powered',
@@ -335,11 +335,11 @@ public function testBlockCacheTags() {
     );
     sort($expected_cache_tags);
     $this->assertIdentical($cache_entry->tags, $expected_cache_tags);
-    $cache_entry = \Drupal::cache('render')->get('entity_view:block:powered:en:stark');
+    $cache_entry = \Drupal::cache('render')->get('entity_view:block:powered:en:classy');
     $expected_cache_tags = array(
       'block_view',
       'block:powered',
-      'theme:stark',
+      'theme:classy',
       'block_plugin:system_powered_by_block',
       'rendered',
     );
@@ -368,7 +368,7 @@ public function testBlockCacheTags() {
     $cid = sha1(implode(':', $cid_parts));
     $cache_entry = \Drupal::cache('render')->get($cid);
     $expected_cache_tags = array(
-      'theme:stark',
+      'theme:classy',
       'theme_global_settings',
       'block_view',
       'block:powered-2',
@@ -381,22 +381,22 @@ public function testBlockCacheTags() {
     $expected_cache_tags = array(
       'block_view',
       'block:powered',
-      'theme:stark',
+      'theme:classy',
       'block_plugin:system_powered_by_block',
       'rendered',
     );
     sort($expected_cache_tags);
-    $cache_entry = \Drupal::cache('render')->get('entity_view:block:powered:en:stark');
+    $cache_entry = \Drupal::cache('render')->get('entity_view:block:powered:en:classy');
     $this->assertIdentical($cache_entry->tags, $expected_cache_tags);
     $expected_cache_tags = array(
       'block_view',
       'block:powered-2',
-      'theme:stark',
+      'theme:classy',
       'block_plugin:system_powered_by_block',
       'rendered',
     );
     sort($expected_cache_tags);
-    $cache_entry = \Drupal::cache('render')->get('entity_view:block:powered-2:en:stark');
+    $cache_entry = \Drupal::cache('render')->get('entity_view:block:powered-2:en:classy');
     $this->assertIdentical($cache_entry->tags, $expected_cache_tags);
 
     // The plugin providing the "Powered by Drupal" block is modified; verify a
@@ -428,7 +428,7 @@ public function testUninstallTheme() {
     $this->drupalGet('<front>');
     $this->assertText('Powered by Drupal');
 
-    $theme_handler->setDefault('stark');
+    $theme_handler->setDefault('classy');
     $theme_handler->uninstall(['seven']);
 
     // Ensure that the block configuration does not exist anymore.
diff --git a/core/modules/block/src/Tests/BlockUiTest.php b/core/modules/block/src/Tests/BlockUiTest.php
index 7b6f945..bd0af2b 100644
--- a/core/modules/block/src/Tests/BlockUiTest.php
+++ b/core/modules/block/src/Tests/BlockUiTest.php
@@ -82,7 +82,7 @@ protected function setUp() {
   public function testBlockDemoUiPage() {
     $this->drupalPlaceBlock('system_help_block', array('region' => 'help'));
     $this->drupalGet('admin/structure/block');
-    $this->clickLink(t('Demonstrate block regions (@theme)', array('@theme' => 'Stark')));
+    $this->clickLink(t('Demonstrate block regions (@theme)', array('@theme' => 'Classy')));
     $elements = $this->xpath('//div[contains(@class, "region-highlighted")]/div[contains(@class, "block-region") and contains(text(), :title)]', array(':title' => 'Highlighted'));
     $this->assertTrue(!empty($elements), 'Block demo regions are shown.');
   }
@@ -134,7 +134,7 @@ public function testCandidateBlockList() {
     $arguments = array(
       ':ul_class' => 'block-list',
       ':li_class' => 'test-block-instantiation',
-      ':href' => 'admin/structure/block/add/test_block_instantiation/stark',
+      ':href' => 'admin/structure/block/add/test_block_instantiation/classy',
       ':text' => 'Display message',
     );
 
@@ -158,7 +158,7 @@ public function testContextAwareBlocks() {
     $arguments = array(
       ':ul_class' => 'block-list',
       ':li_class' => 'test-context-aware',
-      ':href' => 'admin/structure/block/add/test_context_aware/stark',
+      ':href' => 'admin/structure/block/add/test_context_aware/classy',
       ':text' => 'Test context-aware block',
     );
 
@@ -173,7 +173,7 @@ public function testContextAwareBlocks() {
    * Tests that the BlockForm populates machine name correctly.
    */
   public function testMachineNameSuggestion() {
-    $url = 'admin/structure/block/add/test_block_instantiation/stark';
+    $url = 'admin/structure/block/add/test_block_instantiation/classy';
     $this->drupalGet($url);
     $this->assertFieldByName('id', 'displaymessage', 'Block form uses raw machine name suggestion when no instance already exists.');
     $this->drupalPostForm($url, array(), 'Save block');
@@ -195,16 +195,16 @@ public function testBlockPlacementIndicator() {
     // Select the 'Powered by Drupal' block to be placed.
     $block = array();
     $block['id'] = strtolower($this->randomMachineName());
-    $block['theme'] = 'stark';
+    $block['theme'] = 'classy';
     $block['region'] = 'content';
 
     // After adding a block, it will indicate which block was just added.
     $this->drupalPostForm('admin/structure/block/add/system_powered_by_block', $block, t('Save block'));
-    $this->assertUrl('admin/structure/block/list/stark?block-placement=' . drupal_html_class($block['id']));
+    $this->assertUrl('admin/structure/block/list/classy?block-placement=' . drupal_html_class($block['id']));
 
     // Resaving the block page will remove the block indicator.
     $this->drupalPostForm(NULL, array(), t('Save blocks'));
-    $this->assertUrl('admin/structure/block/list/stark');
+    $this->assertUrl('admin/structure/block/list/classy');
   }
 
 }
diff --git a/core/modules/block/src/Tests/Views/DisplayBlockTest.php b/core/modules/block/src/Tests/Views/DisplayBlockTest.php
index 3c0deab..37b8b60 100644
--- a/core/modules/block/src/Tests/Views/DisplayBlockTest.php
+++ b/core/modules/block/src/Tests/Views/DisplayBlockTest.php
@@ -66,7 +66,7 @@ public function testBlockCategory() {
       ':li_class' => 'views-block' . drupal_html_class($edit['id']) . '-block-1',
       ':href' => \Drupal::Url('block.admin_add', array(
         'plugin_id' => 'views_block:' . $edit['id'] . '-block_1',
-        'theme' => 'stark',
+        'theme' => 'classy',
       )),
       ':text' => $edit['label'],
     );
@@ -105,7 +105,7 @@ public function testBlockCategory() {
       ':li_class' => 'views-block' . drupal_html_class($edit['id']) . '-block-2',
       ':href' => \Drupal::Url('block.admin_add', array(
         'plugin_id' => 'views_block:' . $edit['id'] . '-block_2',
-        'theme' => 'stark',
+        'theme' => 'classy',
       )),
       ':text' => $edit['label'],
     );
@@ -117,7 +117,7 @@ public function testBlockCategory() {
       ':li_class' => 'views-block' . drupal_html_class($edit['id']) . '-block-3',
       ':href' => \Drupal::Url('block.admin_add', array(
         'plugin_id' => 'views_block:' . $edit['id'] . '-block_3',
-        'theme' => 'stark',
+        'theme' => 'classy',
       )),
       ':text' => $edit['label'],
     );
diff --git a/core/modules/block/tests/modules/block_test/config/install/block.block.test_block.yml b/core/modules/block/tests/modules/block_test/config/install/block.block.test_block.yml
index f52790f..be7e06c 100644
--- a/core/modules/block/tests/modules/block_test/config/install/block.block.test_block.yml
+++ b/core/modules/block/tests/modules/block_test/config/install/block.block.test_block.yml
@@ -13,5 +13,5 @@ dependencies:
   module:
     - block_test
   theme:
-    - stark
+    - classy
 visibility: {  }
diff --git a/core/modules/block_content/src/Tests/BlockContentTypeTest.php b/core/modules/block_content/src/Tests/BlockContentTypeTest.php
index 76dfdb7..f6e2efc 100644
--- a/core/modules/block_content/src/Tests/BlockContentTypeTest.php
+++ b/core/modules/block_content/src/Tests/BlockContentTypeTest.php
@@ -144,7 +144,7 @@ public function testsBlockContentAddTypes() {
 
     // Install all themes.
     \Drupal::service('theme_handler')->install(array('bartik', 'seven'));
-    $themes = array('bartik', 'seven', 'stark');
+    $themes = array('bartik', 'seven', 'classy');
     $theme_settings = $this->container->get('config.factory')->get('system.theme');
     foreach ($themes as $default_theme) {
       // Change the default theme.
@@ -152,7 +152,7 @@ public function testsBlockContentAddTypes() {
       \Drupal::service('router.builder')->rebuild();
 
       // For each installed theme, go to its block page and test the redirects.
-      $themes = array('bartik', 'stark', 'seven');
+      $themes = array('bartik', 'classy', 'seven');
       foreach ($themes as $theme) {
         // Test that adding a block from the 'place blocks' form sends you to the
         // block configure form.
diff --git a/core/modules/block_content/tests/modules/block_content_test/config/install/block.block.foobargorilla.yml b/core/modules/block_content/tests/modules/block_content_test/config/install/block.block.foobargorilla.yml
index a39088a..ed83291 100644
--- a/core/modules/block_content/tests/modules/block_content_test/config/install/block.block.foobargorilla.yml
+++ b/core/modules/block_content/tests/modules/block_content_test/config/install/block.block.foobargorilla.yml
@@ -6,7 +6,7 @@ dependencies:
   theme:
     - stark
 id: foobargorilla
-theme: stark
+theme: classy
 region: content
 weight: null
 provider: null
diff --git a/core/modules/menu_ui/src/Tests/MenuCacheTagsTest.php b/core/modules/menu_ui/src/Tests/MenuCacheTagsTest.php
index 0614cd4..ba19651 100644
--- a/core/modules/menu_ui/src/Tests/MenuCacheTagsTest.php
+++ b/core/modules/menu_ui/src/Tests/MenuCacheTagsTest.php
@@ -48,7 +48,7 @@ public function testMenuBlock() {
 
     // Verify a cache hit, but also the presence of the correct cache tags.
     $expected_tags = array(
-      'theme:stark',
+      'theme:classy',
       'theme_global_settings',
       'rendered',
       'block_view',
@@ -106,7 +106,7 @@ public function testMenuBlock() {
     $this->verifyPageCache($path, 'MISS');
 
     // Verify a cache hit.
-    $this->verifyPageCache($path, 'HIT', array('rendered', 'theme:stark', 'theme_global_settings'));
+    $this->verifyPageCache($path, 'HIT', array('rendered', 'theme:classy', 'theme_global_settings'));
   }
 
 }
diff --git a/core/modules/search/src/Tests/SearchBlockTest.php b/core/modules/search/src/Tests/SearchBlockTest.php
index 9aca60f..deadeed 100644
--- a/core/modules/search/src/Tests/SearchBlockTest.php
+++ b/core/modules/search/src/Tests/SearchBlockTest.php
@@ -36,7 +36,7 @@ protected function testSearchFormBlock() {
 
     // Test availability of the search block in the admin "Place blocks" list.
     $this->drupalGet('admin/structure/block');
-    $this->assertLinkByHref('/admin/structure/block/add/search_form_block/stark', 0,
+    $this->assertLinkByHref('/admin/structure/block/add/search_form_block/classy', 0,
       'Did not find the search block in block candidate list.');
 
     $block = $this->drupalPlaceBlock('search_form_block');
diff --git a/core/modules/simpletest/src/KernelTestBase.php b/core/modules/simpletest/src/KernelTestBase.php
index d947caa..f26c5d4 100644
--- a/core/modules/simpletest/src/KernelTestBase.php
+++ b/core/modules/simpletest/src/KernelTestBase.php
@@ -203,7 +203,7 @@ protected function setUp() {
       $this->enableModules($modules);
     }
     // In order to use theme functions default theme config needs to exist.
-    \Drupal::config('system.theme')->set('default', 'stark');
+    \Drupal::config('system.theme')->set('default', 'classy');
 
     // Tests based on this class are entitled to use Drupal's File and
     // StreamWrapper APIs.
diff --git a/core/modules/system/src/Tests/Bootstrap/PageCacheTest.php b/core/modules/system/src/Tests/Bootstrap/PageCacheTest.php
index e8a9d1c..5e34817 100644
--- a/core/modules/system/src/Tests/Bootstrap/PageCacheTest.php
+++ b/core/modules/system/src/Tests/Bootstrap/PageCacheTest.php
@@ -65,7 +65,7 @@ function testPageCacheTags() {
       'pre_render',
       'rendered',
       'system_test_cache_tags_page',
-      'theme:stark',
+      'theme:classy',
       'theme_global_settings',
     );
     $this->assertIdentical($cache_entry->tags, $expected_tags);
diff --git a/core/modules/system/src/Tests/Entity/EntityCacheTagsTestBase.php b/core/modules/system/src/Tests/Entity/EntityCacheTagsTestBase.php
index ddea749..2bd830b 100644
--- a/core/modules/system/src/Tests/Entity/EntityCacheTagsTestBase.php
+++ b/core/modules/system/src/Tests/Entity/EntityCacheTagsTestBase.php
@@ -283,7 +283,7 @@ public function testReferencedEntity() {
     $nonempty_entity_listing_path = 'entity_test/list_labels_alphabetically/' . $entity_type;
 
     $render_cache_tags = array('rendered');
-    $theme_cache_tags = array('theme:stark', 'theme_global_settings');
+    $theme_cache_tags = array('theme:classy', 'theme_global_settings');
 
     $view_cache_tag = array();
     if ($this->entity->getEntityType()->hasHandlerClass('view_builder')) {
@@ -327,7 +327,7 @@ public function testReferencedEntity() {
     $tags = Cache::mergeTags($render_cache_tags, $theme_cache_tags, $referencing_entity_cache_tags);
     $this->verifyPageCache($referencing_entity_path, 'HIT', $tags);
     // Also verify the existence of an entity render cache entry.
-    $cid = 'entity_view:entity_test:' . $this->referencing_entity->id() . ':full:stark:r.anonymous:' . date_default_timezone_get();
+    $cid = 'entity_view:entity_test:' . $this->referencing_entity->id() . ':full:classy:r.anonymous:' . date_default_timezone_get();
     $tags = Cache::mergeTags($render_cache_tags, $referencing_entity_cache_tags);
     $this->verifyRenderCache($cid, $tags);
 
@@ -337,7 +337,7 @@ public function testReferencedEntity() {
     $tags = Cache::mergeTags($render_cache_tags, $theme_cache_tags, $non_referencing_entity_cache_tags);
     $this->verifyPageCache($non_referencing_entity_path, 'HIT', $tags);
     // Also verify the existence of an entity render cache entry.
-    $cid = 'entity_view:entity_test:' . $this->non_referencing_entity->id() . ':full:stark:r.anonymous:' . date_default_timezone_get();
+    $cid = 'entity_view:entity_test:' . $this->non_referencing_entity->id() . ':full:classy:r.anonymous:' . date_default_timezone_get();
     $tags = Cache::mergeTags($render_cache_tags, $non_referencing_entity_cache_tags);
     $this->verifyRenderCache($cid, $tags);
 
diff --git a/core/modules/system/src/Tests/Entity/EntityWithUriCacheTagsTestBase.php b/core/modules/system/src/Tests/Entity/EntityWithUriCacheTagsTestBase.php
index 95aea0c..958e041 100644
--- a/core/modules/system/src/Tests/Entity/EntityWithUriCacheTagsTestBase.php
+++ b/core/modules/system/src/Tests/Entity/EntityWithUriCacheTagsTestBase.php
@@ -44,7 +44,7 @@ public function testEntityUri() {
     // Also verify the existence of an entity render cache entry, if this entity
     // type supports render caching.
     if (\Drupal::entityManager()->getDefinition($entity_type)->isRenderCacheable()) {
-      $cid = 'entity_view:' . $entity_type . ':' . $this->entity->id() . ':' . $view_mode . ':stark:r.anonymous:' . date_default_timezone_get();
+      $cid = 'entity_view:' . $entity_type . ':' . $this->entity->id() . ':' . $view_mode . ':classy:r.anonymous:' . date_default_timezone_get();
       $cache_entry = \Drupal::cache('render')->get($cid);
       $expected_cache_tags = Cache::mergeTags($cache_tag, $view_cache_tag, $this->getAdditionalCacheTagsForEntity($this->entity), array($render_cache_tag));
       $this->verifyRenderCache($cid, $expected_cache_tags);
diff --git a/core/modules/system/src/Tests/Installer/InstallerTranslationTest.php b/core/modules/system/src/Tests/Installer/InstallerTranslationTest.php
index fb0a236..5707234 100644
--- a/core/modules/system/src/Tests/Installer/InstallerTranslationTest.php
+++ b/core/modules/system/src/Tests/Installer/InstallerTranslationTest.php
@@ -65,7 +65,7 @@ public function testInstaller() {
     $edit = array('preprocess_css' => FALSE);
     $this->drupalPostForm('admin/config/development/performance', $edit, t('Save configuration'));
     $this->drupalGet('<front>');
-    $this->assertRaw('stark/css/layout.css');
+    $this->assertRaw('classy/css/layout.css');
   }
 
 }
diff --git a/core/modules/system/src/Tests/Menu/MenuRouterTest.php b/core/modules/system/src/Tests/Menu/MenuRouterTest.php
index 48c7500..640754e 100644
--- a/core/modules/system/src/Tests/Menu/MenuRouterTest.php
+++ b/core/modules/system/src/Tests/Menu/MenuRouterTest.php
@@ -247,7 +247,6 @@ public function testThemeIntegration() {
       ->set('default', $this->default_theme)
       ->set('admin', $this->admin_theme)
       ->save();
-    $theme_handler->uninstall(array('stark'));
 
     $this->doTestThemeCallbackMaintenanceMode();
 
diff --git a/core/modules/system/src/Tests/Theme/ThemeEarlyInitializationTest.php b/core/modules/system/src/Tests/Theme/ThemeEarlyInitializationTest.php
index 04730d2..af21a56 100644
--- a/core/modules/system/src/Tests/Theme/ThemeEarlyInitializationTest.php
+++ b/core/modules/system/src/Tests/Theme/ThemeEarlyInitializationTest.php
@@ -33,6 +33,6 @@ function testRequestListener() {
     $this->assertRaw('Themed output generated in a KernelEvents::REQUEST listener');
     // Verify that the default theme's CSS still appears even though the theme
     // system was initialized early.
-    $this->assertRaw('stark/css/layout.css');
+    $this->assertRaw('classy/css/layout.css');
   }
 }
diff --git a/core/modules/system/tests/modules/theme_test/src/Theme/HighPriorityThemeNegotiator.php b/core/modules/system/tests/modules/theme_test/src/Theme/HighPriorityThemeNegotiator.php
index 8d93267..7934ae3 100644
--- a/core/modules/system/tests/modules/theme_test/src/Theme/HighPriorityThemeNegotiator.php
+++ b/core/modules/system/tests/modules/theme_test/src/Theme/HighPriorityThemeNegotiator.php
@@ -26,7 +26,7 @@ public function applies(RouteMatchInterface $route_match) {
    * {@inheritdoc}
    */
   public function determineActiveTheme(RouteMatchInterface $route_match) {
-    return 'stark';
+    return 'classy';
   }
 
 }
diff --git a/core/modules/system/tests/themes/test_theme/test_theme.info.yml b/core/modules/system/tests/themes/test_theme/test_theme.info.yml
index e35a15d..fd5aae5 100644
--- a/core/modules/system/tests/themes/test_theme/test_theme.info.yml
+++ b/core/modules/system/tests/themes/test_theme/test_theme.info.yml
@@ -12,6 +12,7 @@ name: 'Test theme'
 type: theme
 description: 'Theme for testing the theme system'
 version: VERSION
+base theme: classy
 core: 8.x
 stylesheets-remove:
   - system.module.css
diff --git a/core/modules/tour/src/Tests/TourCacheTagsTest.php b/core/modules/tour/src/Tests/TourCacheTagsTest.php
index ab376e2..085477a 100644
--- a/core/modules/tour/src/Tests/TourCacheTagsTest.php
+++ b/core/modules/tour/src/Tests/TourCacheTagsTest.php
@@ -49,7 +49,7 @@ public function testRenderedTour() {
 
     // Verify a cache hit, but also the presence of the correct cache tags.
     $expected_tags = array(
-      'theme:stark',
+      'theme:classy',
       'theme_global_settings',
       'tour:tour-test',
       'rendered',
@@ -70,7 +70,7 @@ public function testRenderedTour() {
     $this->verifyPageCache($path, 'MISS');
 
     // Verify a cache hit.
-    $this->verifyPageCache($path, 'HIT', array('rendered', 'theme:stark', 'theme_global_settings'));
+    $this->verifyPageCache($path, 'HIT', array('rendered', 'theme:classy', 'theme_global_settings'));
   }
 
 }
diff --git a/core/profiles/testing/config/install/system.theme.yml b/core/profiles/testing/config/install/system.theme.yml
new file mode 100644
index 0000000..0defc7e
--- /dev/null
+++ b/core/profiles/testing/config/install/system.theme.yml
@@ -0,0 +1,2 @@
+# @todo: Remove this file in https://www.drupal.org/node/2352949
+default: classy
diff --git a/core/profiles/testing/testing.info.yml b/core/profiles/testing/testing.info.yml
index b905706..1eb843d 100644
--- a/core/profiles/testing/testing.info.yml
+++ b/core/profiles/testing/testing.info.yml
@@ -4,3 +4,6 @@ description: 'Minimal profile for running tests. Includes absolutely required mo
 version: VERSION
 core: 8.x
 hidden: true
+# @todo: Remove this in https://www.drupal.org/node/2352949
+themes:
+  - classy
diff --git a/core/themes/classy/classy.info.yml b/core/themes/classy/classy.info.yml
index d557b48..990896e 100644
--- a/core/themes/classy/classy.info.yml
+++ b/core/themes/classy/classy.info.yml
@@ -4,3 +4,7 @@ description: 'A base theme with sensible default CSS classes added. Learn how to
 package: Core
 version: VERSION
 core: 8.x
+
+stylesheets:
+  all:
+    - css/layout.css
diff --git a/core/themes/classy/css/layout.css b/core/themes/classy/css/layout.css
new file mode 100644
index 0000000..79c654f
--- /dev/null
+++ b/core/themes/classy/css/layout.css
@@ -0,0 +1,4 @@
+/**
+ * @file
+ * Classy layout file. Do NOT delete. Needed for testing.
+ */
diff --git a/core/themes/classy/logo.png b/core/themes/classy/logo.png
new file mode 100644
index 0000000..32332cf
--- /dev/null
+++ b/core/themes/classy/logo.png
@@ -0,0 +1,8 @@
+PNG
+
+   IHDR   A   I   ȭ   tEXtSoftware Adobe ImageReadyqe<  IDAThkpTj[Z:S;SVrm%k$@{9r\
+,B5`AmRBYS  bUHT() $~سgs6	${N\vfAOzp~X^EpGZxs/"T7!^O3	KT5syL~M>gG)$$2*	8_(+ѳEAE!A騵皻Vo7'iQPPQQû:;7.8 GF:B@=q2vf$1}e==0О&Ys#J[?ʿrI%D4"*%A#{ C}Yb*Ȧ$tJB-
+\@m\ )Vk:L66*Ijmr?廍9R<LLs MKE%IW}7rbgfVnLB	XtA/xPU&,%8Jvtwb!؊"k?=!H*	=EkgG-,GvDWFdADp|+2On9ykDJERLe=2f#teq*)ֳWMrN2ũf)R+&FmED,h̼J*RW@(<*W/Hbґd!ᣬ3,)Ee3DP` @Lܨ=SA͝Š)Bq?xՐ{Upe,CE+c"Ǡ|QS	aɭqqCRMŵ;H6!c	hi|Xϥ,(H7lP8!	%pgYg9
+͸jP$*~9: KÄpc&Ű* (!-qmi31b&T`: aoqw&ӫ9XivA6$!!B>)Ap̎U}1jNuԔ٫	2 	P&jdamˆJ@ҟĩւ~sub9lڊsDVB	4HY3MľSGdֆ8PbR 	=!QC%I%Lle?!v'n׀h UΏ^#4\6QYQvLހQj=Nưg7?EU9%s~P+h "L`!><p,AM0sQK綏3fӽBl+M䈍vlgYM(2cDE̹Fܧ.^L;F0j[Lŉ l4Ml;-s7S;)M	gk>eotWZW(-Z&Z鞝8:lK,:'2z>gwt0ۡ#ii["$g潧c1@ Ss Fy}u״&,b?c]Q6&zC'csY\(Y;8rEyjxq7Ax;Pvzɤ<QՄNݷ(68MlaqďLwO;+j$t%o{`x2_WI?~v	+_K=Ĉ1,`n*R#_+VrV"xw#~T" 7llgOƉK`#l㢄38hb1BGZC'iOVjv8x'|g
+~s /Tx4{)$L{	8(D(m8U'J~gn=;rM2dJxqSCJj3DЂ[qd?%a^fq%aVC9v&^ҟ|9t)2`d9\fFZTg;y0[
+y/	"Iq#v7I-5#-ZsG#.#'lğ6kh]/ghK 8&&1Y?hxAZqCOH_i DU{{Yi)/yo{%闟vyӆXpmDn/+.gc\Xe_j[6:v[unWa_{    IENDB`
\ No newline at end of file

diff --git a/core/modules/system/src/Tests/System/ThemeTest.php b/core/modules/system/src/Tests/System/ThemeTest.php
index 1534675..96e2300 100644
--- a/core/modules/system/src/Tests/System/ThemeTest.php
+++ b/core/modules/system/src/Tests/System/ThemeTest.php
@@ -48,7 +48,7 @@ function testThemeSettings() {
     // Specify a filesystem path to be used for the logo.
     $file = current($this->drupalGetTestFiles('image'));
     $file_relative = strtr($file->uri, array('public:/' => PublicStream::basePath()));
-    $default_theme_path = 'core/themes/stark';
+    $default_theme_path = 'core/themes/classy';
 
     $supported_paths = array(
       // Raw stream wrapper URI.
@@ -192,7 +192,7 @@ function testAdministrationTheme() {
     $this->assertRaw('core/themes/seven', 'Administration theme used on an administration page.');
 
     $this->drupalGet('node/' . $this->node->id());
-    $this->assertRaw('core/themes/stark', 'Site default theme used on node page.');
+    $this->assertRaw('core/themes/classy', 'Site default theme used on node page.');
 
     $this->drupalGet('node/add');
     $this->assertRaw('core/themes/seven', 'Administration theme used on the add content page.');
@@ -218,7 +218,7 @@ function testAdministrationTheme() {
     $this->drupalLogin($this->admin_user);
 
     $this->drupalGet('node/add');
-    $this->assertRaw('core/themes/stark', 'Site default theme used on the add content page.');
+    $this->assertRaw('core/themes/classy', 'Site default theme used on the add content page.');
 
     // Reset to the default theme settings.
     $edit = array(
@@ -228,10 +228,10 @@ function testAdministrationTheme() {
     $this->drupalPostForm('admin/appearance', $edit, t('Save configuration'));
 
     $this->drupalGet('admin');
-    $this->assertRaw('core/themes/stark', 'Site default theme used on administration page.');
+    $this->assertRaw('core/themes/classy', 'Site default theme used on administration page.');
 
     $this->drupalGet('node/add');
-    $this->assertRaw('core/themes/stark', 'Site default theme used on the add content page.');
+    $this->assertRaw('core/themes/classy', 'Site default theme used on the add content page.');
   }
 
   /**
@@ -249,10 +249,10 @@ function testSwitchDefaultTheme() {
     $this->assertText('Bartik(' . t('active tab') . ')', 'Default local task on blocks admin page is the default theme.');
     // Switch back to Stark and test again to test that the menu cache is cleared.
     $this->drupalGet('admin/appearance');
-    // Stark is the second 'Set as default' link.
-    $this->clickLink(t('Set as default'), 1);
+    // Classy is the first 'Set as default' link.
+    $this->clickLink(t('Set as default'), 0);
     $this->drupalGet('admin/structure/block');
-    $this->assertText('Stark(' . t('active tab') . ')', 'Default local task on blocks admin page has changed.');
+    $this->assertText('Classy(' . t('active tab') . ')', 'Default local task on blocks admin page has changed.');
   }
 
   /**